from PandaPrimes import primes_range
import numpy

def _PRIME_LIST():
    path_to_primes = "/".join(__file__.split("/")[:-1]) + "/primes.txt"
    with open(path_to_primes,"r") as file:
        primes = numpy.array(list(map(int, file.read().split(", "))))
    return primes

def test_primes_range():
    primes = _PRIME_LIST()
    for index, prime in enumerate(primes_range(10**6)):
        assert primes[index] == prime

if __name__ == "__main__":
    test_primes_range()


from PandaPrimes import *

def test_get_nth_prime():
    assert get_nth_prime(10**9) == 22801763489
    assert get_nth_prime(10**9,10**6) == 22803640037
    assert get_nth_prime(10**9,10**4) == 22801792709

def test_count_primes():
    assert count_primes(10**9) == 50847534
    assert count_primes(1,10**10) == 455052511

def test_count_twins():
    assert count_twins(10**9) == 3424506

def test_is_prime():
    assert is_prime(18446744073709551557)

if __name__ == "__main__":
    test_count_primes()
    test_count_twins()
    test_get_nth_prime()
    test_is_prime()
    


from PandaPrimes import Iterator
import numpy

def _PRIME_LIST():
    path_to_primes = "/".join(__file__.split("/")[:-1]) + "/primes.txt"
    with open(path_to_primes,"r") as file:
        primes = numpy.array(list(map(int, file.read().split(", "))))
    return primes

def test_Iterator():
    primes = _PRIME_LIST()
    it = Iterator()
    for i in range(len(primes)):
        assert primes[i] == it.next_prime()
    for i in range(0,len(primes),-1):
        assert primes[i] == it.prev_prime()

    it.jump_to(47)
    assert it.next_prime() == 47
    assert it.prev_prime() == 43

    it.jump_to(4180410070769835979)

    assert it.next_prime() == 4180410070769835979
    assert it.next_prime() == 4180410070769836039

_PRIME_LIST()


from PandaPrimes import generate_primes, generate_n_primes
import numpy
from time import time
from sys import getsizeof

def _PRIME_LIST():
    path_to_primes = "/".join(__file__.split("/")[:-1]) + "/primes.txt"
    with open(path_to_primes,"r") as file:
        primes = numpy.array(list(map(int, file.read().split(", "))))
    return primes

def test_generate_primes():
    primes = _PRIME_LIST()
    assert numpy.array_equal(generate_primes(10**6), primes)
    
def test_n_generate_primes():
    n = 10000
    primes = _PRIME_LIST()
    assert numpy.array_equal(generate_n_primes(n),primes[:n])
    start = int(primes[n])
    assert numpy.array_equal(generate_n_primes(n,start), primes[n:n*2])
    

def generation_performance():
    started = time()
    primes = generate_primes(10**10)
    ended = time()
    size = getsizeof(primes) // (1024 ** 2)
    print(f"enrated primes from 2 to 10^10 in {(ended-started):.3f}s\nWith size of {size} MB")

if __name__ == "__main__":
    test_generate_primes()
    test_n_generate_primes()
    generation_performance()



from setuptools import Extension, setup
import os

class get_numpy_include(object):
    def __str__(self):
        import numpy
        return numpy.get_include()


with open("README.md", "r") as readme_file:
    README = readme_file.read()

PandaPrimes_ext = Extension(
            name="PandaPrimes.PandaPrimes",
             sources=["PandaPrimes/src/PandaPrimes.c"],
             libraries=["primesieve"],
             include_dirs=[get_numpy_include()],            
        )

setup(
    version="0.0.2",
    setup_requires = ["numpy"],
    install_requires=['setuptools',
                      'numpy>=1.26.0'],
    packages=["PandaPrimes"],
    package_dir={'PandaPrimes': 'PandaPrimes'},
    ext_modules=[PandaPrimes_ext],
    project_urls={
        "Source": "https://github.com/PaNDa2code/PandaPrimes",
    },
    author="PaNDa2code",
    author_email="moaaz0688@gmail.com",
    description="A Python extension module for finding primes using C",
    long_description=README,
    long_description_content_type="text/markdown",
)
